@@ -21,9 +21,9 @@ class Calendar(object):
             try:
                 self._impl = _holDict[holCenter]()
             except KeyError:
-                raise ValueError("{0} is not a valid description of a holiday center")
+                raise ValueError("{0} is not a valid description of a holiday center".format(holCenter))
         else:
-            raise ValueError("{0} is not a valid description of a holiday center")
+            raise ValueError("{0} is not a valid description of a holiday center".format(holCenter))
 
     def isBizDay(self, d):
         return self._impl.isBizDay(d)
@@ -135,7 +135,7 @@ class Calendar(object):
 
     def holDatesList(self, fromDate, toDate, includeWeekEnds=True):
         pyFinAssert(fromDate <= toDate, ValueError, "from date ({0} must be earlier than to date {1}"
-                 .format(fromDate, toDate))
+                   .format(fromDate, toDate))
         result = []
         d = fromDate
         while d <= toDate:
